@@ -162,6 +162,8 @@ class PSMTemplate():
         self.divider_height = 0.45
         self.title_block_font_size = 10
 
+        self.note_title = "Notes:" # First line of notes
+
         return
 
 
@@ -366,7 +368,7 @@ class PSMTemplate():
         canvas.translate(self.padding.left*cm,self.padding.bottom*cm)
         canvas.setFont("Arial",self.note_font_size)
         note_height = max((self.title_block_height-1)*cm,self.note_font_size*(len(self.notes)+1))+1*cm
-        canvas.drawString(0.5*cm,note_height,"Notes:")
+        canvas.drawString(0.5*cm,note_height,self.note_title)
         
         note_counter = 1
         for n in self.notes:
